"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = require("path");
const lodash_1 = require("lodash");
function createRoot(extensionsPaths, aspectPaths, rootExtensionName) {
    return __awaiter(this, void 0, void 0, function* () {
        const rootId = rootExtensionName ? `'${rootExtensionName}'` : '';
        return `
import { Harmony } from '@teambit/harmony';
import UIAspect from './ui.aspect';
import UIRuntime from './ui.ui.runtime';
${getImportStatements(aspectPaths, 'Aspect')}
${getImportStatements(extensionsPaths, 'Runtime')}

Harmony.load([UIAspect, ${getIdentifiers(aspectPaths, 'Aspect')}], 'ui', {})
  .then((harmony) => {
    harmony
      .run()
      .then(() => {
        const uiExtension = harmony.get('teambit.bit/ui');
        uiExtension.render(${rootId});
      })
      .catch((err) => {
        throw err;
      });
  });
  `;
    });
}
exports.createRoot = createRoot;
function getImportStatements(extensionPaths, suffix) {
    return extensionPaths.map((path) => `import ${getIdentifier(path, suffix)} from '${path}';`).join('\n');
}
function getIdentifiers(extensionsPaths, suffix) {
    return extensionsPaths.map((path) => `${getIdentifier(path, suffix)}`).join(', ');
}
function getIdentifier(path, suffix) {
    return lodash_1.camelCase(`${path_1.parse(path).name.split('.')[0]}${suffix}`);
}
//# sourceMappingURL=create-root.js.map