import { SlotRegistry } from '@teambit/harmony';
import { CLIMain } from '@teambit/cli';
import type { GraphqlMain } from '@teambit/graphql';
import { UIRoot } from './ui-root';
import { ExpressMain } from '@teambit/express';
import type { ComponentMain } from '@teambit/component';
import { UIServer } from './ui-server';
import { Logger, LoggerMain } from '@teambit/logger';
import type { AspectMain } from '@teambit/aspect';
export declare type UIDeps = [CLIMain, GraphqlMain, ExpressMain, ComponentMain, LoggerMain, AspectMain];
export declare type UIRootRegistry = SlotRegistry<UIRoot>;
export declare type OnStart = () => void;
export declare type OnStartSlot = SlotRegistry<OnStart>;
export declare type UIConfig = {
    port?: number;
    portRange: [number, number];
};
export declare type RuntimeOptions = {
    uiRootName?: string;
    pattern?: string;
    dev?: boolean;
    port?: number;
};
export declare class UiMain {
    private config;
    private graphql;
    private uiRootSlot;
    private express;
    private onStartSlot;
    private componentExtension;
    private logger;
    constructor(config: UIConfig, graphql: GraphqlMain, uiRootSlot: UIRootRegistry, express: ExpressMain, onStartSlot: OnStartSlot, componentExtension: ComponentMain, logger: Logger);
    build(uiRootName?: string): Promise<any>;
    createRuntime({ uiRootName, pattern, dev, port }: RuntimeOptions): Promise<UIServer>;
    getPort(port?: number): Promise<number>;
    registerOnStart(onStartFn: OnStart): this;
    private invokeOnStart;
    registerUiRoot(uiRoot: UIRoot): void;
    getUi(uiRootName?: string): [string, UIRoot];
    getUiRootOrThrow(uiRootName: string): UIRoot;
    createLink(extensionPaths: string[], aspectPaths: string[], rootExtensionName: string): Promise<string>;
    generateRoot(extensionPaths: string[], aspectPaths: string[], rootExtensionName: string): Promise<string>;
    private selectPort;
    static defaultConfig: {
        portRange: number[];
    };
    static runtime: import("@teambit/harmony").RuntimeDefinition;
    static dependencies: import("@teambit/harmony").Aspect[];
    static slots: (((registerFn: () => string) => SlotRegistry<UIRoot>) | ((registerFn: () => string) => SlotRegistry<OnStart>))[];
    static provider([cli, graphql, express, componentExtension, loggerMain]: UIDeps, config: any, [uiRootSlot, onStartSlot]: [UIRootRegistry, OnStartSlot]): Promise<UiMain>;
}
